@@ -42,7 +42,7 @@ mnl <- function(
 
   vars <- c(rvar, evar)
 
-  if (is_empty(wts, "None")) {
+  if (radiant.data::is_empty(wts, "None")) {
     wts <- NULL
   } else if (is_string(wts)) {
     wtsname <- wts
@@ -52,7 +52,7 @@ mnl <- function(
   df_name <- if (is_string(dataset)) dataset else deparse(substitute(dataset))
   dataset <- get_data(dataset, vars, filt = data_filter, envir = envir)
 
-  if (!is_empty(wts)) {
+  if (!radiant.data::is_empty(wts)) {
     if (exists("wtsname")) {
       wts <- dataset[[wtsname]]
       dataset <- select_at(dataset, .vars = base::setdiff(colnames(dataset), wtsname))
@@ -218,7 +218,7 @@ summary.mnl <- function(
 
   cat("Multinomial logistic regression (MNL)")
   cat("\nData                 :", object$df_name)
-  if (!is_empty(object$data_filter)) {
+  if (!radiant.data::is_empty(object$data_filter)) {
     cat("\nFilter               :", gsub("\\n", "", object$data_filter))
   }
   cat("\nResponse variable    :", object$rvar)
@@ -259,7 +259,7 @@ summary.mnl <- function(
   ## pseudo R2 (likelihood ratio) - http://en.wikipedia.org/wiki/Logistic_Model
   mnl_fit %<>% mutate(r2 = (null.deviance - deviance) / null.deviance) %>%
     round(dec)
-  if (!is_empty(object$wts, "None") && (length(unique(object$wts)) > 2 || min(object$wts) >= 1)) {
+  if (!radiant.data::is_empty(object$wts, "None") && (length(unique(object$wts)) > 2 || min(object$wts) >= 1)) {
     nobs <- sum(object$wts)
     mnl_fit$BIC <- round(-2 * mnl_fit$logLik + ln(nobs) * with(mnl_fit, edf), dec)
   } else {
@@ -321,7 +321,7 @@ summary.mnl <- function(
     }
   }
 
-  if (!is_empty(test_var)) {
+  if (!radiant.data::is_empty(test_var)) {
     if (any(grepl("stepwise", object$check))) {
       cat("Model comparisons are not conducted when Stepwise has been selected.\n")
     } else {
@@ -401,7 +401,7 @@ plot.mnl <- function(
 ) {
 
   if (is.character(x) || !inherits(x$model, "multinom")) return(x)
-  if (is_empty(plots[1])) return("Please select a mnl regression plot from the drop-down menu")
+  if (radiant.data::is_empty(plots[1])) return("Please select a mnl regression plot from the drop-down menu")
 
   model <- x$model$model
   rvar <- x$rvar
@@ -542,7 +542,7 @@ predict.mnl <- function(
       # if (is.null(dim(pred_val))) pred_val <- t(pred_val)
       if (is.vector(pred_val)) pred_val <- t(pred_val)
       pred_val %<>% as.data.frame(stringsAsFactors = FALSE)
-      if (all(is_empty(pred_names))) pred_names <- colnames(pred_val)
+      if (all(radiant.data::is_empty(pred_names))) pred_names <- colnames(pred_val)
       pred_val %<>% select(1:min(ncol(pred_val), length(pred_names))) %>%
         set_colnames(pred_names)
     }
@@ -592,7 +592,7 @@ plot.mnl.predict <- function(
 ) {
 
   ## should work with req in regress_ui but doesn't
-  if (is_empty(xvar)) return(invisible())
+  if (radiant.data::is_empty(xvar)) return(invisible())
 
   if (facet_col != "." && facet_row == facet_col) {
     return("The same variable cannot be used for both Facet row and Facet column")
@@ -653,7 +653,7 @@ store.mnl.predict <- function(dataset, object, name = NULL, ...) {
   ## as.vector removes all attributes from df
   df <- as.vector(object[, pvars])
 
-  if (is_empty(name)) {
+  if (radiant.data::is_empty(name)) {
     name <- pvars
   } else {
     ## gsub needed because trailing/leading spaces may be added to the variable name
