@@ -226,8 +226,8 @@ output$ui_logit_show_interactions <- renderUI({
 output$ui_logit_int <- renderUI({
   choices <- character(0)
   if (isolate("logit_show_interactions" %in% names(input)) &&
-    is_empty(input$logit_show_interactions)) {
-  } else if (is_empty(input$logit_show_interactions)) {
+   radiant.data::is_empty(input$logit_show_interactions)) {
+  } else if (radiant.data::is_empty(input$logit_show_interactions)) {
     return()
   } else {
     vars <- input$logit_evar
@@ -358,7 +358,7 @@ output$ui_logistic <- renderUI({
           "input.logit_predict == 'data' | input.logit_predict == 'datacmd'",
           tags$table(
             tags$td(textInput("logit_store_pred_name", "Store predictions:", state_init("logit_store_pred_name", "pred_logit"))),
-            tags$td(actionButton("logit_store_pred", "Store", icon = icon("plus")), style = "padding-top:30px;")
+            tags$td(actionButton("logit_store_pred", "Store", icon = icon("plus")), class = "top")
           )
         )
       ),
@@ -395,7 +395,7 @@ output$ui_logistic <- renderUI({
         tags$table(
           # tags$td(textInput("logit_store_res_name", "Store residuals:", state_init("logit_store_res_name", "residuals_logit"))),
           tags$td(uiOutput("ui_logit_store_res_name")),
-          tags$td(actionButton("logit_store_res", "Store", icon = icon("plus")), style = "padding-top:30px;")
+          tags$td(actionButton("logit_store_res", "Store", icon = icon("plus")), class = "top")
         )
       )
     ),
@@ -408,7 +408,7 @@ output$ui_logistic <- renderUI({
 
 logit_plot <- reactive({
   if (logit_available() != "available") return()
-  if (is_empty(input$logit_plots, "none")) return()
+  if (radiant.data::is_empty(input$logit_plots, "none")) return()
 
   plot_height <- 500
   plot_width <- 650
@@ -517,11 +517,11 @@ logit_available <- reactive({
 .predict_logistic <- reactive({
   if (not_pressed(input$logit_run)) return("** Press the Estimate button to estimate the model **")
   if (logit_available() != "available") return(logit_available())
-  if (is_empty(input$logit_predict, "none")) return("** Select prediction input **")
-  if ((input$logit_predict == "data" || input$logit_predict == "datacmd") && is_empty(input$logit_pred_data)) {
+  if (radiant.data::is_empty(input$logit_predict, "none")) return("** Select prediction input **")
+  if ((input$logit_predict == "data" || input$logit_predict == "datacmd") && radiant.data::is_empty(input$logit_pred_data)) {
     return("** Select data for prediction **")
   }
-  if (input$logit_predict == "cmd" && is_empty(input$logit_pred_cmd)) {
+  if (input$logit_predict == "cmd" && radiant.data::is_empty(input$logit_pred_cmd)) {
     return("** Enter prediction commands **")
   }
 
@@ -542,7 +542,7 @@ logit_available <- reactive({
   req(
     pressed(input$logit_run), input$logit_pred_plot,
     available(input$logit_xvar),
-    !is_empty(input$logit_predict, "none")
+    !radiant.data::is_empty(input$logit_predict, "none")
   )
 
   withProgress(message = "Generating prediction plot", value = 1, {
@@ -553,7 +553,7 @@ logit_available <- reactive({
 .plot_logistic <- reactive({
   if (not_pressed(input$logit_run)) {
     return("** Press the Estimate button to estimate the model **")
-  } else if (is_empty(input$logit_plots, "none")) {
+  } else if (radiant.data::is_empty(input$logit_plots, "none")) {
     return("Please select a logistic regression plot from the drop-down menu")
   } else if (logit_available() != "available") {
     return(logit_available())
@@ -574,14 +574,14 @@ observeEvent(input$logistic_report, {
   inp_out <- list("", "")
   inp_out[[1]] <- clean_args(logit_sum_inputs(), logit_sum_args[-1])
   figs <- FALSE
-  if (!is_empty(input$logit_plots, "none")) {
+  if (!radiant.data::is_empty(input$logit_plots, "none")) {
     inp_out[[2]] <- clean_args(logit_plot_inputs(), logit_plot_args[-1])
     inp_out[[2]]$custom <- FALSE
     outputs <- c(outputs, "plot")
     figs <- TRUE
   }
 
-  if (!is_empty(input$logit_store_res_name)) {
+  if (!radiant.data::is_empty(input$logit_store_res_name)) {
     fixed <- fix_names(input$logit_store_res_name)
     updateTextInput(session, "logit_store_res_name", value = fixed)
     xcmd <- paste0(input$dataset, " <- store(", input$dataset, ", result, name = \"", fixed, "\")\n")
@@ -589,17 +589,17 @@ observeEvent(input$logistic_report, {
     xcmd <- ""
   }
 
-  if (!is_empty(input$logit_predict, "none") &&
-     (!is_empty(input$logit_pred_data) || !is_empty(input$logit_pred_cmd))) {
+  if (!radiant.data::is_empty(input$logit_predict, "none") &&
+     (!radiant.data::is_empty(input$logit_pred_data) || !radiant.data::is_empty(input$logit_pred_cmd))) {
     pred_args <- clean_args(logit_pred_inputs(), logit_pred_args[-1])
 
-    if (!is_empty(pred_args$pred_cmd)) {
+    if (!radiant.data::is_empty(pred_args$pred_cmd)) {
       pred_args$pred_cmd <- strsplit(pred_args$pred_cmd, ";")[[1]]
     } else {
       pred_args$pred_cmd <- NULL
     }
 
-    if (!is_empty(pred_args$pred_data)) {
+    if (!radiant.data::is_empty(pred_args$pred_data)) {
       pred_args$pred_data <- as.symbol(pred_args$pred_data)
     } else {
       pred_args$pred_data <- NULL
@@ -619,7 +619,7 @@ observeEvent(input$logistic_report, {
     }
     # xcmd <- paste0(xcmd, "\n# write.csv(pred, file = \"~/logit_predictions.csv\", row.names = FALSE)")
 
-    if (input$logit_pred_plot && !is_empty(input$logit_xvar)) {
+    if (input$logit_pred_plot && !radiant.data::is_empty(input$logit_xvar)) {
       inp_out[[3 + figs]] <- clean_args(logit_pred_plot_inputs(), logit_pred_plot_args[-1])
       inp_out[[3 + figs]]$result <- "pred"
       outputs <- c(outputs, "plot")
@@ -652,7 +652,7 @@ observeEvent(input$logit_store_res, {
 })
 
 observeEvent(input$logit_store_pred, {
-  req(!is_empty(input$logit_pred_data), pressed(input$logit_run))
+  req(!radiant.data::is_empty(input$logit_pred_data), pressed(input$logit_run))
   pred <- .predict_logistic()
   if (is.null(pred)) return()
   fixed <- unlist(strsplit(input$logit_store_pred_name, "(\\s*,\\s*|\\s*;\\s*)")) %>%
